@@ -1,5 +1,5 @@
 from SigProfilerTopography.source.commons import *
-from SigProfilerTopography.source.nucleosomeoccupancy import *
+from SigProfilerTopography.source.occupancy import *
 from SigProfilerTopography.source.replicationtime import *
 from SigProfilerTopography.source.replicationstrandbias import *
 from SigProfilerTopography.source.transcriptionstrandbias import *
